// mozileCopyCutPaste.js

/* ***** BEGIN LICENSE BLOCK *****
 * Licensed under Version: MPL 1.1/GPL 2.0/LGPL 2.1
 * Full Terms at http://mozile.mozdev.org/license.html
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Playsophy code.
 *
 * The Initial Developer of the Original Code is Playsophy
 * Portions created by the Initial Developer are Copyright (C) 2002-2003
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *		Karl Guertin <grayrest@grayrest.com>
 *		James A. Overton <james@overton.ca>
 *		Christian Stocker (Bitflux)
 *		Paul Everitt
 *		David Palm
 *
 * ***** END LICENSE BLOCK ***** */

/*******

Mozile Copy Cut Paste Javascript
Mozile version 0.60

Created by James A. Overton
Created on 2004-03-24

Last revised by James A. Overton
Last revised on 2004-03-24

HISTORY:
	Some code in this file was first found in mozilehtmltb.js, while the 
majority was cut out of mozileTB.js and separated into different files.


DESCRIPTION:
	This file handles the mozileCopu, mozileCut, and mozilePaste functions,
as well as some other code related to the clipboard.

*********/



/********** Clipboard Functionality *************/


// Mozile Paste
// Takes the content of the system clipboard and inserts it at the current selection.
// Right now only plain text is handled.

function mozilePaste() {
	mozileDo("Paste");

	var clipboard = mozilla.getClipboard();
	// only get text for now: POST04: need XHTML validator first so that correct
	// HTML comes first.
	var text = clipboard.getData(MozClipboard.TEXT_FLAVOR);
	if(text)
	{
		mozileSelection.insertNode(mozileTarget.document.createTextNode(text));
	}
} // end mozilePaste()



// Mozile Copy
// Copies the selected text to the system clipboard.
// The selection is currently copied as plain text.

function mozileCopy() {
	mozileDo("Copy");

	var cssr = mozileSelection.getEditableRange();

	if(!cssr || cssr.collapsed) // not an editable area or nothing selected
		return;

	// data to save - render as text (temporary thing - move to html later)
	var text = cssr.toString();

	var clipboard = mozilla.getClipboard();

	// clipboard.setData(deletedFragment.saveXML(), "text/html"); // go back to this once, paste supports html paste!
	clipboard.setData(text, MozClipboard.TEXT_FLAVOR);
} // end mozileCopy()




// Mozile Cut
// Copy the current selection to the system clipboard, then remove it from the document.
// Works in plain text.

function mozileCut() {
	mozileDo("Cut");

	var cssr = mozileSelection.getEditableRange();

	if(!cssr || cssr.collapsed) // not an editable area or nothing selected
		return;

	var clipboard = mozilla.getClipboard();

	// data to save - render as text (temporary thing)
	var text = cssr.toString();

	var deletedFragment = cssr.extractContentsByCSS();

	// clipboard.setData(deletedFragment.saveXML(), MozClipboard.HTML_FLAVOR); // go back to this once, paste supports html paste!
	clipboard.setData(text, MozClipboard.TEXT_FLAVOR);

	mozileSelection.removeAllRanges();
	mozileSelection.addRange(cssr);
} // end mozileCut()





